@@ -1,13 +1,13 @@
-#' @rdname wtd_sd
+#' @rdname weighted_sd
 #' @export
-wtd_chisqtest <- function(data, ...) {
-  UseMethod("wtd_chisqtest")
+weighted_chisqtest <- function(data, ...) {
+  UseMethod("weighted_chisqtest")
 }
 
 #' @importFrom dplyr select
-#' @rdname wtd_sd
+#' @rdname weighted_sd
 #' @export
-wtd_chisqtest.default <- function(data, x, y, weights, ...) {
+weighted_chisqtest.default <- function(data, x, y, weights, ...) {
   x.name <- deparse(substitute(x))
   y.name <- deparse(substitute(y))
   w.name <- deparse(substitute(weights))
@@ -25,14 +25,14 @@ wtd_chisqtest.default <- function(data, x, y, weights, ...) {
   dat <- na.omit(dat)
 
   colnames(dat)[3] <- ".weights"
-  xtab_statistics(data = dat, statistics = "auto", weights = ".weights", ...)
+  crosstable_statistics(data = dat, statistics = "auto", weights = ".weights", ...)
 }
 
 
 #' @importFrom stats xtabs
-#' @rdname wtd_sd
+#' @rdname weighted_sd
 #' @export
-wtd_chisqtest.formula <- function(formula, data, ...) {
+weighted_chisqtest.formula <- function(formula, data, ...) {
   vars <- all.vars(formula)
 
   if (length(vars) < 3) {
@@ -42,5 +42,5 @@ wtd_chisqtest.formula <- function(formula, data, ...) {
 
   tab <- as.table(round(stats::xtabs(data[[vars[3]]] ~ data[[vars[1]]] + data[[vars[2]]])))
   class(tab) <- "table"
-  xtab_statistics(data = tab, statistics = "auto", weights = NULL, ...)
+  crosstable_statistics(data = tab, statistics = "auto", weights = NULL, ...)
 }
